<?php

class VodDecadesScreen extends AbstractPreloadedRegularScreen
    implements UserInputHandler
{
    const ID = 'vod_decades';

    public static function get_media_url_str()
    {
        return MediaURL::encode(array('screen_id' => self::ID));
    }

    ///////////////////////////////////////////////////////////////////////

    private $vod;

    public function __construct(Vod $vod)
    {
        $this->vod = $vod;

        parent::__construct(self::ID,
            $vod->get_vod_decades_folder_views());

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $select_decade_action =
            UserInputHandlerRegistry::create_action(
                $this, 'select_decade');

        return array
        (
            GUI_EVENT_KEY_ENTER => $select_decade_action,
        );
    }

    public function get_handler_id()
    {
        return self::ID;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Vod decades: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if ($user_input->control_id == 'select_decade') {
            if (!isset($user_input->selected_media_url))
                return null;

            $caption = $user_input->selected_media_url;
            $media_url_str = $this->vod->get_decades_media_url_str($user_input->selected_media_url);

            return ActionFactory::open_folder($media_url_str, $caption);
        }

        return null;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $this->vod->ensure_decades_loaded($plugin_cookies);

        $decades = $this->vod->get_decades();

        $items = array();

        foreach ($decades as $decade => $value) {

            $caption = $decade;
            $media_url_str = $decade;
            $icon_url = '';

            $items[] = array
            (
                PluginRegularFolderItem::media_url => $media_url_str,
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => $icon_url,
                )
            );
        }

        return $items;
    }

    public function get_archive(MediaURL $media_url)
    {
        return $this->vod->get_archive($media_url);
    }
}

?>

