<?php

class VodYearsScreen extends AbstractPreloadedRegularScreen
    implements UserInputHandler
{
    const ID = 'vod_years';

    public static function get_media_url_str($page_name, $arg = null)
    {
        $arr['screen_id'] = self::ID;
        $arr['page_name'] = $page_name;
        if ($page_name === 'decade')
            $arr['decade'] = $arg;
        return MediaURL::encode($arr);

    }

    ///////////////////////////////////////////////////////////////////////

    private $vod;

    public function __construct(Vod $vod)
    {
        $this->vod = $vod;

        parent::__construct(self::ID,
            $vod->get_vod_years_folder_views());

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $select_year_action =
            UserInputHandlerRegistry::create_action(
                $this, 'select_year');

        return array
        (
            GUI_EVENT_KEY_ENTER => $select_year_action,
        );
    }

    public function get_handler_id()
    {
        return self::ID;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Vod years: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if ($user_input->control_id == 'select_year') {
            if (!isset($user_input->selected_media_url))
                return null;

            $caption = $user_input->selected_media_url;
            $media_url_str = $this->vod->get_years_media_url_str($user_input->selected_media_url);

            return ActionFactory::open_folder($media_url_str, $caption);
        }

        return null;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $this->vod->ensure_decades_loaded($plugin_cookies);

        $decade = $media_url->decade;

        $years = $this->vod->get_years($decade);

        $items = array();

        foreach ($years as $year => $value) {

            $caption = $year;
            $media_url_str = $year;
            $icon_url = '';

            $items[] = array
            (
                PluginRegularFolderItem::media_url => $media_url_str,
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => $icon_url,
                )
            );
        }

        return $items;
    }

    public function get_archive(MediaURL $media_url)
    {
        return $this->vod->get_archive($media_url);
    }
}

?>

